Mongorestypes enum

Inheritance
Available extensions

Values

abstime → const Mongorestypes
bool → const Mongorestypes
date → const Mongorestypes
daterange → const Mongorestypes
float4 → const Mongorestypes
float8 → const Mongorestypes
int2 → const Mongorestypes
int4 → const Mongorestypes
int4range → const Mongorestypes
int8 → const Mongorestypes
int8range → const Mongorestypes
json → const Mongorestypes
jsonb → const Mongorestypes
money → const Mongorestypes
numeric → const Mongorestypes
oid → const Mongorestypes
reltime → const Mongorestypes
time → const Mongorestypes
text → const Mongorestypes
timestamp → const Mongorestypes
timestamptz → const Mongorestypes
timetz → const Mongorestypes
tsrange → const Mongorestypes
tstzrange → const Mongorestypes

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Mongorestypes>
A constant List of the values in this enum, in order of their declaration.