PasubotQueryBuilder class

Inheritance
Available extensions

Constructors

PasubotQueryBuilder(String url, RealtimeClient realtime, {Map<String, String> headers = const {}, required String schema, required String table, Client? httpClient, required int incrementId, required YAJsonIsolate isolate})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSPromise<T>

Available on Future<T>, provided by the FutureOfJSAnyToJSPromise extension

A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.
no setter
toJS JSPromise<JSAny?>

Available on Future<void>, provided by the FutureOfVoidToJSPromise extension

A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.
no setter

Methods

appendSearchParams(String key, String value, [Uri? url]) Uri
Get new Uri with updated queryParams Uses lists to allow multiple values for the same key
inherited
asStream() Stream
Creates a Stream containing the result of this future.
inherited
catchError(Function onError, {bool test(Object error)?}) Future
Handles errors emitted by this Future.
inherited
count([CountOption option = CountOption.exact]) MongorestFilterBuilder<int>
Only performs a count query on the table or view.
inherited
delete() MongorestFilterBuilder
Perform a DELETE on the table or view.
inherited
ignore() → void

Available on Future<T>, provided by the FutureExtensions extension

Completely ignores this future and its result.
insert(Object values, {bool defaultToNull = true}) MongorestFilterBuilder
Perform an INSERT into the table or view.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError<E extends Object>(FutureOr<T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) Future<T>

Available on Future<T>, provided by the FutureExtensions extension

Handles errors on this future.
overrideSearchParams(String key, String value) Uri
Get new Uri with overridden queryParams
inherited
select([String columns = '*']) MongorestFilterBuilder<MongorestList>
Perform a SELECT query on the table or view.
inherited
stream({required List<String> primaryKey}) PasubotStreamFilterBuilder
Returns real-time data from your table as a Stream.
then<U>(FutureOr<U> onValue(dynamic value), {Function? onError}) Future<U>
Register callbacks to be called when this future completes.
inherited
timeout(Duration timeLimit, {FutureOr onTimeout()?}) Future
Stop waiting for this future after timeLimit has passed.
inherited
toString() String
A string representation of this object.
inherited
update(Map values) MongorestFilterBuilder
Perform an UPDATE on the table or view.
inherited
upsert(Object values, {String? onConflict, bool ignoreDuplicates = false, bool defaultToNull = true}) MongorestFilterBuilder
Perform an UPSERT on the table or view.
inherited
whenComplete(FutureOr<void> action()) Future
Registers a function to be called when this future completes.
inherited
withConverter<U>(MongorestConverter<U, dynamic> converter) MongorestBuilder<U, U, dynamic>
Converts any response that comes from the server into a type-safe response.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited